@@ -373,19 +373,36 @@ gg_vals <- function(layer = "fill", column = layer, cols = NULL, ...) {
   return(values)
 }
 
-.font_global <- function(font, quiet = TRUE, when_not = NA, ...) {
-  temp <- font_exists(font, ...)
-  if (!any(isTRUE(temp))) {
-    if (isFALSE(is.na(font[1]))) {
-      if (isTRUE(font[1] != "") && !quiet) {
-        warning(sprintf("Font(s) %s not installed, with other name, or can't be found", v2t(font)))
-      }
-      Sys.unsetenv("LARES_FONT") # So R doesn't try again by default
-      font <- when_not
-    }
+.font_global <- function(font, quiet = FALSE, when_not = NA, ask_install = FALSE, ...) {
+  if ("ignore" %in% tolower(font)) {
+    return(NULL)
   } else {
-    # Return first one that is found
-    font <- font[head(which(temp), 1)]
+    temp <- font_exists(font, ...)
+    if (!any(isTRUE(temp))) {
+      if (isFALSE(is.na(font[1]))) {
+        if (isTRUE(font[1] != "") && !quiet) {
+          if (ask_install & font[1] %in% list.files(system.file("fonts", package = "lares"))) {
+            yes <- readline(sprintf("Do you want to install %s font for better results? [y/n]: ", font))
+            if ("y" %in% yes) try(install_localfont(font))
+          } else {
+            warning(sprintf("Font(s) %s not installed, with other name, or can't be found", v2t(font)))
+          }
+        }
+        Sys.unsetenv("LARES_FONT") # So R doesn't try again by default
+        font <- when_not
+      }
+    } else {
+      # Return first one that is found
+      font <- font[head(which(temp), 1)]
+    }
+    return(font)
   }
-  return(font)
+}
+
+install_localfont <- function(
+    font, dir = system.file(paste0("fonts/", gsub(" ", "_", font)), package = "lares"),
+    ...) {
+  try_require("extrafont")
+  font_import(dir, prompt = FALSE, ...)
+  # loadfonts(quiet = TRUE)
 }
